@@ -48,12 +48,13 @@ def relinfo_children(df, root):
     dfs = []
 
     for col in df.columns:
-        namec = pd.Series([x.attrib['name'] for x in root[col][0]], dtype='object')
-        namec.name = 'name'
-        typec = pd.Series([x.attrib['type'] for x in root[col][0]], dtype='object')
-        typec.name = 'type'
-        d = pd.concat([namec, typec], 1)
-        dfs.append(d)
+        if df[col].hasChildren == '1':
+            namec = pd.Series([x.attrib['name'] for x in root[col][0]], dtype='object')
+            namec.name = 'name'
+            typec = pd.Series([x.attrib['type'] for x in root[col][0]], dtype='object')
+            typec.name = 'type'
+            d = pd.concat([namec, typec], 1)
+            dfs.append(d)
 
     df = df.append(pd.Series(dfs, name='children'))
     return df
